# st-fb-post

Streamlit Component, for Facebook Post UI

authors - [@gamcoh](https://github.com/gamcoh) 

## Installation

Install `streamlit-fb-post` with pip
```bash
pip install streamlit-fb-post
```

usage, import the `message` function from `streamlit_fb_post`
```py
import streamlit as st
from streamlit_fb_post import post

post("Happy birthday to the main character in our family!", legend="25 feb", link="https://www.facebook.com/")
```
   
